'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.preprocessor = undefined;

var _fsExtra = require('fs-extra');

var _path = require('path');

var _inlineSourceMapComment = require('inline-source-map-comment');

var _inlineSourceMapComment2 = _interopRequireDefault(_inlineSourceMapComment);

var _babelCore = require('babel-core');

var babel = _interopRequireWildcard(_babelCore);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const resolveConfigFile = opts => {
    if (typeof opts.configFile !== 'string') return {};
    try {
        const settings = { encoding: 'utf8', flag: 'r' };
        const configFilePath = (0, _path.join)(process.cwd(), opts.configFile);
        const configFile = (0, _fsExtra.readFileSync)(configFilePath, settings);
        return JSON.parse(configFile);
    } catch (e) {
        return e;
    }
};

const resolveConfig = opts => {
    if (typeof opts !== 'object') return {};
    const required = {
        sourceMaps: true,
        sourceFileName: null,
        sourceMapTarget: null
    };
    const configFile = resolveConfigFile(opts);
    if (configFile instanceof Error) return configFile;
    return Object.assign({}, configFile, opts, required);
};

const preprocessor = (events, system, opts) => {
    const babelConfig = resolveConfig(opts);
    if (babelConfig instanceof Error) return system.handleError(babelConfig);
    events.onLoad = () => {};
    events.onFileLoad = (source, filename, key) => {
        const tmpFilename = (0, _path.join)(system.tmpDirectory, 'babel', key);
        babelConfig.sourceFileName = filename;
        babelConfig.sourceMapTarget = tmpFilename;

        const transpiled = babel.transform(source, babelConfig);
        const sourceMapComment = (0, _inlineSourceMapComment2.default)(transpiled.map);
        const sourceWithMap = transpiled.code + '\n' + sourceMapComment;

        (0, _fsExtra.ensureFileSync)(tmpFilename);
        (0, _fsExtra.writeFileSync)(tmpFilename, sourceWithMap);

        return {
            filename: tmpFilename,
            source: transpiled.code,
            key: key
        };
    };
    events.onExit = () => {};
};

exports.preprocessor = preprocessor;